@@ -2,20 +2,17 @@
 import logging
 import json
 
-from typing import Any
+from typing import Any, Callable
 
 from inelsmqtt.util import DeviceValue
 from inelsmqtt import InelsMqtt
+from inelsmqtt.const import Platform, Element
 from inelsmqtt.const import (
     BATTERY,
     DEVICE_TYPE_DICT,
     FRAGMENT_DOMAIN,
     INELS_DEVICE_TYPE_DICT,
     MANUFACTURER,
-    RFTC_10_G,
-    RFTI_10B,
-    SENSOR,
-    BUTTON,
     TEMP_IN,
     TEMP_OUT,
     TEMPERATURE,
@@ -55,10 +52,10 @@ class Device(object):
         fragments = state_topic.split("/")
 
         self.__mqtt = mqtt
-        self.__device_type = DEVICE_TYPE_DICT[
+        self.__device_type: Platform = DEVICE_TYPE_DICT[
             fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]
         ]
-        self.__inels_type = INELS_DEVICE_TYPE_DICT[
+        self.__inels_type: Element = INELS_DEVICE_TYPE_DICT[
             fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]
         ]
         self.__unique_id = fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]
@@ -66,7 +63,10 @@ class Device(object):
         self.__state_topic = state_topic
         self.__set_topic = None
 
-        if self.__device_type is not SENSOR and self.__device_type is not BUTTON:
+        if (
+            self.__device_type is not Platform.SENSOR
+            and self.__device_type is not Platform.BUTTON
+        ):
             self.__set_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/set/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: E501
 
         self.__connected_topic = f"{fragments[TOPIC_FRAGMENTS[FRAGMENT_DOMAIN]]}/connected/{fragments[TOPIC_FRAGMENTS[FRAGMENT_SERIAL_NUMBER]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_DEVICE_TYPE]]}/{fragments[TOPIC_FRAGMENTS[FRAGMENT_UNIQUE_ID]]}"  # noqa: E501
@@ -75,9 +75,11 @@ class Device(object):
         self.__state: Any = None
         self.__values: DeviceValue = None
         self.__features: dict[str] = self.__set_features(self.__inels_type)
+        self.__listeners = dict[str, Callable[[Any], Any]]()
 
         # subscribe availability
         self.__mqtt.subscribe(self.__connected_topic, 0, None, None)
+        self.__mqtt.subscribe_listener(state_topic, self._callback)
 
     @property
     def unique_id(self) -> str:
@@ -98,7 +100,12 @@ class Device(object):
         return self.__mqtt.is_subscribed(self.__state_topic)
 
     @property
-    def inels_type(self) -> str:
+    def listeners(self) -> dict[str, Callable[[Any], Any]]:
+        """List of registered listeners on device"""
+        return self.__listeners
+
+    @property
+    def inels_type(self) -> Element:
         """Get inels type of the device
 
         Returns:
@@ -107,11 +114,11 @@ class Device(object):
         return self.__inels_type
 
     @property
-    def device_type(self) -> str:
+    def device_type(self) -> Platform:
         """Get type of the device
 
         Returns:
-            str: Type
+            Platform: Type
         """
         return self.__device_type
 
@@ -166,6 +173,15 @@ class Device(object):
         """
         return self.__state_topic
 
+    @property
+    def connected_topic(self) -> str:
+        """Connected topic
+
+        Returns:
+            str: string of the connected topic
+        """
+        return self.__connected_topic
+
     @property
     def domain(self) -> str:
         """Domain name of the topic
@@ -208,6 +224,10 @@ class Device(object):
         """List of features of device."""
         return self.__features
 
+    def subscribe_listerner(self, topic: str, fnc: Callable[[Any], Any]) -> None:
+        """Append new item into the datachage listener."""
+        self.__listeners[topic] = fnc
+
     def update_value(self, new_value: Any) -> DeviceValue:
         """Update value after broker change it."""
         return self.__get_value(new_value)
@@ -229,13 +249,22 @@ class Device(object):
         """Set device features."""
         features: dict[str] = None
 
-        if inels_type == RFTI_10B:
+        if inels_type == Element.RFTI_10B:
             features = [TEMP_IN, TEMP_OUT, BATTERY]
-        elif inels_type == RFTC_10_G:
+        elif inels_type == Element.RFTC_10_G:
             features = [TEMPERATURE, BATTERY]
+        elif inels_type == Element.RFSTI_11B:
+            features = [TEMPERATURE]
 
         return features
 
+    def _callback(self, new_value: Any) -> None:
+        """Get value from mqtt when arrived."""
+        self.update_value(new_value)
+
+        for listener in self.__listeners:
+            listener(new_value)
+
     def get_value(self) -> DeviceValue:
         """Get value from inels
 
@@ -282,7 +311,7 @@ class Device(object):
         """
         info = {
             "name": self.__title,
-            "device_type": self.__device_type,
+            "device_type": self.__device_type.value,
             "id": self.__unique_id,
             "via_device": self.__parent_id,
         }
